Logo Navs
Type/Module Description

AVal

AValExtensions

dotnet interop friendly API for adaptive and changeable data

AvaloniaRouter

A router that is specialized to work with Avalonia types. This router will render any object that inherits from Avalonia's of Control.

Interop

A module that contains the interop functions to use the Route class from other languages. It is mostly the same API but using Func instead of F# function types.

Route

RouterOutlet

RouterOutletExtensions

Routes

Represents a collection of routes in the application.

RoutesExtensions

Type something to start searching.