Logo Navs

AvaloniaRouter Type

A router that is specialized to work with Avalonia types. This router will render any object that inherits from Avalonia's of Control.

Constructors

Constructor Description

AvaloniaRouter(routes, ?splash, ?logger)

Full Usage: AvaloniaRouter(routes, ?splash, ?logger)

Parameters:
    routes : RouteDefinition<Control> seq - The routes that the router will use to match the URL and render the view
    ?splash : Func<Control> - The router initially doesn't have a view to render. You can provide this function to supply a splash-like (like mobile devices initial screen) view to render while you trigger the first navigation.
    ?logger : ILogger - An optional logger to log the router's activity

Returns: AvaloniaRouter
routes : RouteDefinition<Control> seq

The routes that the router will use to match the URL and render the view

?splash : Func<Control>

The router initially doesn't have a view to render. You can provide this function to supply a splash-like (like mobile devices initial screen) view to render while you trigger the first navigation.

?logger : ILogger

An optional logger to log the router's activity

Returns: AvaloniaRouter

Type something to start searching.