CacheStrategy Type
The strategy that the router will use to cache the views that are rendered when the route is activated.
Union cases
| Union case |
Description
|
Full Usage:
Cache
|
The NoCache strategy makes that the rendered view will be re-rendered every time the route is activated. |
Full Usage:
NoCache
|
The Cache strategy makes that the rendered view will be stored in memory and will be re-used when the route is activated again. |
Instance members
| Instance member |
Description
|
Full Usage:
this.IsCache
Returns: bool
|
|
Full Usage:
this.IsNoCache
Returns: bool
|
|
Navs