Navs.FuncUI Namespace
| Type/Module | Description |
|
|
|
|
A router that is specialized to work with Avalonia.FuncUI types. This router will render any object that implements the IView interface. |
|
|
|
|
|
|
| Type/Module | Description |
|
|
|
|
A router that is specialized to work with Avalonia.FuncUI types. This router will render any object that implements the IView interface. |
|
|
|
|
|
|