Logo Navs

FuncUIRouter Type

A router that is specialized to work with Avalonia.FuncUI types. This router will render any object that implements the IView interface.

Constructors

Constructor Description

FuncUIRouter(routes, ?splash, ?logger)

Full Usage: FuncUIRouter(routes, ?splash, ?logger)

Parameters:
    routes : RouteDefinition<IView> seq - The routes that the router will use to match the URL and render the view
    ?splash : Func<IView> - The router initially doesn't have a view to render. You can provide this function to supply a splash-like (like mobile devices initial screen) view to render while you trigger the first navigation.
    ?logger : ILogger - An optional logger to log the router's activity

Returns: FuncUIRouter
routes : RouteDefinition<IView> seq

The routes that the router will use to match the URL and render the view

?splash : Func<IView>

The router initially doesn't have a view to render. You can provide this function to supply a splash-like (like mobile devices initial screen) view to render while you trigger the first navigation.

?logger : ILogger

An optional logger to log the router's activity

Returns: FuncUIRouter

Type something to start searching.