IComponentContexExtensions Type
Static members
| Static member |
Description
|
Full Usage:
IComponentContexExtensions.useAVal (context, aVal)
Parameters:
IComponentContext
aVal : aval<'T>
Returns: IReadable<'T>
Modifiers: inline Type parameters: 'T |
Subscribes to an adaptive value and returns an IReadable that will emit changes any time The adaptive value gets an update.
|
Full Usage:
IComponentContexExtensions.useCval (context, cVal)
Parameters:
IComponentContext
cVal : cval<'T>
Returns: IWritable<'T>
Type parameters: 'T |
Takes a changeable value and returns an IWritable that will allow you to update and read from it.
|
Full Usage:
IComponentContexExtensions.useRouter (context, router)
Parameters:
IComponentContext
router : IRouter<IView>
Returns: IReadable<IView voption>
Modifiers: inline |
Subscribes to the router and returns an IReadable that emits the view that is being rendered.
|
Navs