IDisposableBag Type
An object that contains multiple disposable objects that can be disposed of when the route is not cached and deactivated.
Instance members
| Instance member |
Description
|
|
|
An object that contains multiple disposable objects that can be disposed of when the route is not cached and deactivated.
| Instance member |
Description
|
|
|