Guard Module
A module that provides functions for route guard responses
Functions and values
| Function or value |
Description
|
|
A guard response that indicates that the navigation should continue
|
|
A guard response that indicates that the navigation should stop and redirect to the specified URL
|
|
A guard response that indicates that the navigation should stop and fail the navigation
|
Navs