Route Type
Static members
| Static member |
Description
|
Full Usage:
Route.Define(name, path, getContent)
Parameters:
string
-
The name of the route
path : string
-
A templated URL that will be used to match this route
getContent : TaskView<'View>
-
The delegate that will be called to render the view when the route is activated
Returns: RouteDefinition<'View>
A route definition
Modifiers: inline Type parameters: 'View |
Defines a route in the application This function should ideally be used from F# as it provides a more idiomatic F# Function signature.
|
Full Usage:
Route.Define(name, path, getContent)
Parameters:
string
-
The name of the route
path : string
-
A templated URL that will be used to match this route
getContent : SyncView<'View>
-
The delegate that will be called to render the view when the route is activated
Returns: RouteDefinition<'View>
A route definition
Modifiers: inline Type parameters: 'View |
Defines a route in the application This function should ideally be used from non-F# languages as it provides a more standard Function signature.
|
Navs