IRouter<'View> Type
Instance members
| Instance member |
Description
|
Full Usage:
this.Content
Returns: aval<'View voption>
Modifiers: abstract |
The current route that is being rendered by the router. This adaptive value will emit the current route that is being rendered by the router.
|
Full Usage:
this.ContentSnapshot
Returns: 'View voption
Modifiers: abstract |
The current route that is being rendered by the router. This is a single value that will return the current route that is being rendered by the router.
|
|
The current route that is being rendered by the router. This adaptive value will emit the current route that is being rendered by the router. It will also however emit None when the router is in a state where it doesn't have a route to render, this could be when the router is just starting up and hasn't navigated to any route yet or when the router failed to navigate.
|
|
The current route that is being rendered by the router. This property will return the current route that is being rendered by the router. It will also however return None when the router is in a state where it doesn't have a route to render, this could be when the router is just starting up and hasn't navigated to any route yet or when the router failed to navigate.
|
Navs