RouteContext Type
The context of the route that is being activated. This can be used to extract the parameters from the URL and extract information about the templated route that is being activated.
Record fields
| Record Field |
Description
|
|
An object that contains objects that should be disposed of when the route is deactivated.
|
Full Usage:
path
Field type: string
|
RAW URL that is being activated
|
An object that contains the segments, query and hash of the URL in a string form.
|
|
An object that contains multiple dictionaries with the parameters that were extracted from the URL either from the url parameters the query string or the hash portion of the URL.
|
Instance members
| Instance member |
Description
|
|
|
Navs