RouteContext Module
Functions and values
| Function or value |
Description
|
Full Usage:
addDisposable arg1 arg2
Parameters:
IDisposable
arg1 : RouteContext
Modifiers: inline |
Adds a disposable object to the route context. This object will be disposed of when the route is deactivated ONLY if the route doesn't have cache enabled
|
Full Usage:
getParam name ctx
Parameters:
string
-
The name of the parameter to get
ctx : RouteContext
-
The route context to get the parameter from
Returns: 'CastedType voption
The parameter value if it exists in the route context and it was succesfully parsed to it's supplied type or None if it doesn't
Modifiers: inline Type parameters: 'CastedType |
Gets a parameter from the "path" or the "query" section of the route context.
|
Full Usage:
getParamSequence name ctx
Parameters:
string
-
The name of the parameter to get
ctx : RouteContext
-
The route context to get the parameter from
Returns: 'CastedType seq
The parameter value if it exists in the query parameters and it was succesfully parsed to it's supplied type or None if it doesn't
Modifiers: inline Type parameters: 'CastedType |
Gets a parameter from the "query" section of the route context. This method will attempt to collect as many ocurrences of the parameter as it can find in the query string.
|
Navs