RouteDefinition<'View> Type
Record fields
| Record Field |
Description
|
|
The strategy that the router will use to cache the views that are rendered when the route is activated.
|
|
The guards that will be executed when the route is activated. If any of them returns false, the route will not be activated.
|
|
The guards that will be executed when the route is deactivated. If any of them returns false, the route will not be deactivated.
|
|
The delegate that will be called to render the view when the route is activated.
|
Full Usage:
name
Field type: string
|
Name used to locate this route for "by-name" route activation
|
Full Usage:
pattern
Field type: string
|
The URL pattern that will be used to match the route and enforce the URL's parameters to be extracted and passed to the view.
|
Navs