Route Module
Functions and values
| Function or value |
Description
|
Full Usage:
cache strategy definition
Parameters:
CacheStrategy
definition : RouteDefinition<'a>
Returns: RouteDefinition<'a>
Modifiers: inline Type parameters: 'a |
This function allows you to define if the route can be restored from an in memory cache or if it should be always re-rendered when activated.
|
Full Usage:
canActivate guard definition
Parameters:
SyncGuard
-
A function that returns a task of boolean
definition : RouteDefinition<'a>
-
The route definition
Returns: RouteDefinition<'a>
The route definition with the guard added
Modifiers: inline Type parameters: 'a |
A function to define if a route can be activated.
|
Full Usage:
canActivateAsync guard definition
Parameters:
AsyncGuard
-
A function that returns a boolean
definition : RouteDefinition<'a>
-
The route definition
Returns: RouteDefinition<'a>
The route definition with the guard added
Modifiers: inline Type parameters: 'a |
A function to define if a route can be activated.
|
Full Usage:
canActivateTask guard definition
Parameters:
TaskGuard
-
A function that returns a task of boolean
definition : RouteDefinition<'a>
-
The route definition
Returns: RouteDefinition<'a>
The route definition with the guard added
Modifiers: inline Type parameters: 'a |
A Task function to define if a route can be activated.
|
Full Usage:
canDeactivate guard definition
Parameters:
SyncGuard
-
A function that returns a task of boolean
definition : RouteDefinition<'a>
-
The route definition
Returns: RouteDefinition<'a>
The route definition with the guard added
Modifiers: inline Type parameters: 'a |
A function to define if a route can be activated.
|
Full Usage:
canDeactivateAsync guard definition
Parameters:
AsyncGuard
-
A function that returns a boolean
definition : RouteDefinition<'a>
-
The route definition
Returns: RouteDefinition<'a>
The route definition with the guard added
Modifiers: inline Type parameters: 'a |
A Task function to define if a route can be deactivated.
|
Full Usage:
canDeactivateTask guard definition
Parameters:
TaskGuard
-
A function that returns a task of boolean.
definition : RouteDefinition<'a>
-
The route definition
Returns: RouteDefinition<'a>
The route definition with the guard added
Modifiers: inline Type parameters: 'a |
A Task function to define if a route can be deactivated.
|
Navs