Navs.Router Namespace
| Type | Description |
|
This object contains parameters and its values that are extracted from the URL when a route is activated. |
|
|
|
| Type | Description |
|
This object contains parameters and its values that are extracted from the URL when a route is activated. |
|
|
|