Navs.Terminal.Gui Namespace
| Type/Module | Description |
|
|
|
|
dotnet interop friendly API for adaptive and changeable data |
|
|
A module that contains the interop functions to use the Route class from other languages. It is mostly the same API but using Func instead of F# function types. |
|
|
|
|
|
|
|
|
A router that is specialized to work with Terminal.Gui types. This router will render any object that inherits from Terminal.Gui's of Window. |
Navs