Logo Navs

TerminalGuiRouter Type

A router that is specialized to work with Terminal.Gui types. This router will render any object that inherits from Terminal.Gui's of Window.

Constructors

Constructor Description

TerminalGuiRouter(routes, ?splash, ?logger)

Full Usage: TerminalGuiRouter(routes, ?splash, ?logger)

Parameters:
    routes : RouteDefinition<Window> seq - The routes that the router will use to match the URL and render the view
    ?splash : Func<Window> - The router initially doesn't have a view to render. You can provide this function to supply a splash-like (like mobile devices initial screen) view to render while you trigger the first navigation.
    ?logger : ILogger - An optional logger to log the router's activity

Returns: TerminalGuiRouter

///

routes : RouteDefinition<Window> seq

The routes that the router will use to match the URL and render the view

?splash : Func<Window>

The router initially doesn't have a view to render. You can provide this function to supply a splash-like (like mobile devices initial screen) view to render while you trigger the first navigation.

?logger : ILogger

An optional logger to log the router's activity

Returns: TerminalGuiRouter

Type something to start searching.