UrlMatch Type
The result of a successful match between a URL and a templated URL
Record fields
| Record Field |
Description
|
Full Usage:
Hash
Field type: string voption
|
The hash of the URL
Example/users#123 will match /users#123 Hash = ValueSome "123" |
|
The matched segments of the URL, this will be used to extract the parameters
Example/:id/:name will match /123/john and the segments will be Params["id"] = 123 Params["name"] = "john" |
|
The matched query parameters of the URL, this will be used to extract the parameters
Example/users?name&age<int> will match /users?name=john&age=30 QueryParams["name"] = "john" QueryParams["age"] = 30 |
Navs