UrlMatchExtensions Type
Static members
| Static member |
Description
|
Full Usage:
UrlMatchExtensions.getFromParams (urlMatch, name)
Parameters:
UrlMatch
-
The match result to get the parameter from
name : string
-
The name of the parameter to get
Returns: 'CastedType voption
The parameter value if it exists in the query parameters or path segments and it was succesfully parsed to it's supplied type or None if it doesn't
Modifiers: inline Type parameters: 'CastedType |
Gets a parameter from the query parameters or segments of the URL
|
Full Usage:
UrlMatchExtensions.getParamFromPath (urlMatch, name)
Parameters:
UrlMatch
-
The match result to get the parameter from
name : string
-
The name of the parameter to get
Returns: 'CastedType voption
The parameter value if it exists in the path segments and it was succesfully parsed to it's supplied type or None if it doesn't
Modifiers: inline Type parameters: 'CastedType |
Gets a parameter from the path segments of the URL
|
Full Usage:
UrlMatchExtensions.getParamFromQuery (urlMatch, name)
Parameters:
UrlMatch
-
The match result to get the parameter from
name : string
-
The name of the parameter to get
Returns: 'CastedType voption
The parameter value if it exists in the query parameters and it was succesfully parsed to it's supplied type or None if it doesn't
Modifiers: inline Type parameters: 'CastedType |
Gets a parameter from the query parameters of the URL
|
Full Usage:
UrlMatchExtensions.getParamSeqFromQuery (urlMatch, name)
Parameters:
UrlMatch
-
The match result to get the parameter from
name : string
-
The name of the parameter to get
Returns: 'CastedType seq voption
The parameter values if it exists in the query parameters and it was succesfully parsed to it's supplied type or None if it doesn't
Modifiers: inline Type parameters: 'CastedType |
Gets a sequence of parameters from the supplied query key in the URL
|
Navs