UrlMatch Module
Functions and values
| Function or value |
Description
|
Full Usage:
UrlMatch.getFromParams name urlMatch
Parameters:
string
-
The name of the parameter to get
urlMatch : UrlMatch
-
The match result to get the parameter from
Returns: 'CastedType voption
The parameter value if it exists in the query parameters or path segments and it was succesfully parsed to it's supplied type or None if it doesn't
Type parameters: 'CastedType |
Gets a parameter from the query parameters or segments of the URL
|
Full Usage:
UrlMatch.getParamFromPath name urlMatch
Parameters:
string
-
The name of the parameter to get
urlMatch : UrlMatch
-
The match result to get the parameter from
Returns: 'CastedType voption
The parameter value if it exists in the path segments and it was succesfully parsed to it's supplied type or None if it doesn't
Type parameters: 'CastedType |
Gets a parameter from the path segments of the URL
|
Full Usage:
UrlMatch.getParamFromQuery name urlMatch
Parameters:
string
-
The name of the parameter to get
urlMatch : UrlMatch
-
The match result to get the parameter from
Returns: 'CastedType voption
The parameter value if it exists in the query parameters and it was succesfully parsed to it's supplied type or None if it doesn't
Type parameters: 'CastedType |
Gets a parameter from the query parameters of the URL
|
Full Usage:
UrlMatch.getParamSeqFromQuery name urlMatch
Parameters:
string
-
The name of the parameter to get
urlMatch : UrlMatch
-
The match result to get the parameter from
Returns: 'CastedType seq voption
The parameter values if it exists in the query parameters and it was succesfully parsed to it's supplied type or None if it doesn't
Type parameters: 'CastedType |
Gets a sequence of parameters from the supplied query key in the URL
|
Navs