UrlTemplates.UrlParser Namespace
| Type/Module | Description |
|
URL query values can be either a single string or a list of strings This is used to represent the query parameters of a URL |
|
|
A URL component can be a segment, a query or a hash Segments are what is commonly known as the "path" of the URL Query is the part of the URL that comes after the "?" and is usually in the form of "key=value", although it can also be in the form of "key" Hash is the part of the URL that comes after the "#" |
|
|
The result of parsing a URL This is used to represent the different components of a URL Since we're just parsing the string, all of the values are strings |
|
|
|
Navs