UrlInfo Type
The result of parsing a URL This is used to represent the different components of a URL Since we're just parsing the string, all of the values are strings
Record fields
| Record Field |
Description
|
Full Usage:
Hash
Field type: string voption
|
The hash of the URL
Example/users#123 will have the hash ValueSome "123" |
|
The query parameters of the URL
Example/users?name&age<int>&optional will have the query parameters { { "name", String "john" } { "age", String "30" } { "optional", ValueNone } } |
Full Usage:
Segments
Field type: string list
|
The segments of the
Example/users/123 will have the segments [ "users"; "123" ] |
Navs