UrlParser Module
Functions and values
| Function or value |
Description
|
|
|
Full Usage:
UrlParser.ofUri uri
Parameters:
Uri
-
The URI to convert to a string
Returns: string
A string representation of the URI which can then be used to parse the URL
|
Takes an existing URI and returns a string representation of it This is particularly useful to enable deep linking in an application. You'd use this function to convert a URI to a string and then use the string
|
Navs