UrlTemplates.UrlTemplate Namespace
| Type/Module | Description |
|
A discriminated union that represents the different types of query parameters that a URL can have |
|
|
A discriminated union that represents the different types of components that a URL can have |
|
|
A discriminated union that represents the different types of segments that a URL can have |
|
|
A few well known types that can be used as as the types for the parameters of a URL. |
|
|
|
|
|
This object is the representation of an URL template including the segments, query parameters and hash and its corresponding types in the case of the segments and query parameters |
Navs