QueryKey Type
A discriminated union that represents the different types of query parameters that a URL can have
Union cases
| Union case |
Description
|
|
A query parameter that is optional in the URL
Example/?name means that the URL can have the query parameter "name" Optional("name", String) |
|
A query parameter that is required in the URL
Example/?name! means that the URL must have the query parameter "name" Required("name", String) |
Instance members
| Instance member |
Description
|
Full Usage:
this.IsOptional
Returns: bool
|
|
Full Usage:
this.IsRequired
Returns: bool
|
|
Navs