Navs.Avalonia Namespace
| Type/Module | Description |
|
|
|
|
dotnet interop friendly API for adaptive and changeable data |
|
|
A router that is specialized to work with Avalonia types. This router will render any object that inherits from Avalonia's of Control. |
|
|
A module that contains the interop functions to use the Route class from other languages. It is mostly the same API but using Func instead of F# function types. |
|
|
|
|
|
|
|
|
|
|
|
Represents a collection of routes in the application. |
|
|
|
Navs