Route Type
Static members
| Static member |
Description
|
Full Usage:
Route.define (name, path, handler)
Parameters:
string
-
The name of the route
path : string
-
A templated URL that will be used to match this route
handler : Func<RouteContext, INavigable<Control>, CancellationToken, Task<Control>>
-
An task returning function to render when the route is activated.
Returns: RouteDefinition<Control>
A route definition
Modifiers: inline |
Defines a route in the application A cancellation token is provided alongside the route context to allow you to support cancellation of the route activation.
|
Full Usage:
Route.define (name, path, handler)
Parameters:
string
-
The name of the route
path : string
-
A templated URL that will be used to match this route
handler : Func<RouteContext, INavigable<Control>, Control>
-
The view to render when the route is activated
Returns: RouteDefinition<Control>
A route definition
Modifiers: inline |
Defines a route in the application
|
Navs