Route Type
Constructors
| Constructor |
Description
|
|
Initializes a new instance of the Route class with a name.
|
Full Usage:
Route(name, path, handler)
Parameters:
string
path : string
handler : RouteContext -> INavigable<Control> -> CancellationToken -> Task<Control>
Returns: Route
|
Initializes a new instance of the Route class with a name and an asynchronous handler.
|
Full Usage:
Route(name, path, handler)
Parameters:
string
path : string
handler : RouteContext -> INavigable<Control> -> Async<Control>
Returns: Route
|
Initializes a new instance of the Route class with a name and an asynchronous handler.
|
Full Usage:
Route(name, path, handler)
Parameters:
string
path : string
handler : RouteContext -> INavigable<Control> -> Control
Returns: Route
|
Initializes a new instance of the Route class with a name and a handler.
|
Instance members
| Instance member |
Description
|
|
Gets the definition of the route.
|
Static members
| Static member |
Description
|
Full Usage:
Route.define (name, path, handler)
Parameters:
string
-
The name of the route
path : string
-
A templated URL that will be used to match this route
handler : RouteContext -> INavigable<Control> -> Control
-
The view to render when the route is activated
Returns: RouteDefinition<Control>
A route definition
|
Defines a route in the application
|
Full Usage:
Route.define (name, path, handler)
Parameters:
string
-
The name of the route
path : string
-
A templated URL that will be used to match this route
handler : RouteContext -> INavigable<Control> -> CancellationToken -> Task<Control>
-
An task returning function to render when the route is activated.
Returns: RouteDefinition<Control>
A route definition
|
Defines a route in the application A cancellation token is provided alongside the route context to allow you to support cancellation of the route activation.
|
Full Usage:
Route.define (name, path, handler)
Parameters:
string
-
The name of the route
path : string
-
A templated URL that will be used to match this route
handler : RouteContext -> INavigable<Control> -> Async<Control>
-
The view to render when the route is activated
Returns: RouteDefinition<Control>
A route definition
|
Defines a route in the application
|
Navs